summaryrefslogtreecommitdiff
path: root/cras/src/server/cras_iodev.c
diff options
context:
space:
mode:
Diffstat (limited to 'cras/src/server/cras_iodev.c')
-rw-r--r--cras/src/server/cras_iodev.c16
1 files changed, 3 insertions, 13 deletions
diff --git a/cras/src/server/cras_iodev.c b/cras/src/server/cras_iodev.c
index fd1ce805..f426eb5f 100644
--- a/cras/src/server/cras_iodev.c
+++ b/cras/src/server/cras_iodev.c
@@ -239,7 +239,7 @@ int cras_iodev_is_zero_volume(const struct cras_iodev *odev)
* | ---------------- | device from
* | | S1 Open | | audio_thread and
* | ---------------- | closes device
* | Device with empty start | |
* | ops transits into | Sample is ready |
* | no stream state right V |
* | after open. ---------------- |
@@ -527,8 +527,8 @@ static void add_ext_dsp_module_to_pipeline(struct cras_iodev *iodev)
if (!pipeline) {
cras_iodev_alloc_dsp(iodev);
- cras_dsp_load_mock_pipeline(iodev->dsp_context,
- iodev->format->num_channels);
+ cras_dsp_load_dummy_pipeline(iodev->dsp_context,
+ iodev->format->num_channels);
pipeline = cras_dsp_get_pipeline(iodev->dsp_context);
}
/* dsp_context mutex locked. Now it's safe to modify dsp
@@ -953,8 +953,6 @@ int cras_iodev_open(struct cras_iodev *iodev, unsigned int cb_level,
iodev->highest_hw_level = 0;
iodev->input_dsp_offset = 0;
- ewma_power_init(&iodev->ewma, iodev->format->frame_rate);
-
if (iodev->direction == CRAS_STREAM_OUTPUT) {
/* If device supports start ops, device can be in open state.
* Otherwise, device starts running right after opening. */
@@ -1099,9 +1097,6 @@ int cras_iodev_put_output_buffer(struct cras_iodev *iodev, uint8_t *frames,
loopback->cb_data);
}
- ewma_power_calculate(&iodev->ewma, (int16_t *)frames,
- iodev->format->num_channels, nframes);
-
rc = apply_dsp(iodev, frames, nframes);
if (rc)
return rc;
@@ -1205,11 +1200,6 @@ int cras_iodev_get_input_buffer(struct cras_iodev *iodev, unsigned int *frames)
*frames - iodev->input_dsp_offset);
if (rc)
return rc;
- ewma_power_calculate_area(
- &iodev->ewma,
- (int16_t *)(hw_buffer +
- iodev->input_dsp_offset * frame_bytes),
- data->area, *frames - iodev->input_dsp_offset);
}
if (cras_system_get_capture_mute())
@@ -239,7 +239,7 @@ int cras_iodev_is_zero_volume(const struct cras_iodev *odev)
* | | S1 Open | | audio_thread and
* | ---------------- | closes device
- * | Device with empty start | |
+ * | Device with dummy start | |
* | ops transits into | Sample is ready |
* | no stream state right V |